﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2008 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using HeuristicLab.CEDMA.DB.Interfaces;
using System.Runtime.Serialization;

namespace HeuristicLab.CEDMA.DB.Interfaces {
  public static class Ontology {
    public static string CedmaNameSpace {
      get { return "http://www.heuristiclab.com/cedma/"; }
    }

    #region model attributes
    public static Entity PredicateModelAttribute {
      get { return new Entity(CedmaNameSpace + "ModelAttribute"); }
    }
    public static Entity PredicateModelAttributeName {
      get { return new Entity(CedmaNameSpace + "ModelAttributeName"); }
    }
    public static Entity PredicateModelAttributeValue {
      get { return new Entity(CedmaNameSpace + "ModelAttributeValue"); }
    }
    public static Entity PredicateModelAttributeType {
      get { return new Entity(CedmaNameSpace + "ModelAttributeType"); }
    }
    /// <summary>
    /// Attribute value is ordinal, values can be sorted.
    /// Examples are quality measures or complexity measures.
    /// </summary>
    public static Entity TypeOrdinalAttribute {
      get { return new Entity(CedmaNameSpace + "TypeOrdinalAttribute"); }
    }
    /// <summary>
    /// Attribute value is categorical and thus can't be sorted.
    /// Examples is target-variable.
    /// </summary>
    public static Entity TypeCategoricalAttribute {
      get { return new Entity(CedmaNameSpace + "TypeCategoricalAttribute"); }
    }
    /// <summary>
    /// Attribute is a quality measure
    /// </summary>
    public static Entity TypeQualityAttribute {
      get { return new Entity(CedmaNameSpace + "TypeQualityAttribute"); }
    }
    /// <summary>
    /// Attribute is a complexity measure
    /// </summary>
    public static Entity TypeComplexityAttribute {
      get { return new Entity(CedmaNameSpace + "TypeComplexityAttribute"); }
    }
    #endregion

    #region meta-data predicates
    public static Entity PredicateName {
      get { return new Entity(CedmaNameSpace + "Name"); }
    }
    /// <summary>
    /// Each entity can have a serialized XML representation that can be loaded in HL.
    /// </summary>
    public static Entity PredicateSerializedData {
      get { return new Entity(CedmaNameSpace + "SerializedData"); }
    }
    /// <summary>
    /// Link from data set to model.
    /// A data set can have multiple models.
    /// </summary>
    public static Entity PredicateHasModel {
      get { return new Entity(CedmaNameSpace + "Model"); }
    }
    /// <summary>
    /// Link from model to algorithm.
    /// An algorithm can generate multiple models, each model is generated by exactly one algorithm.
    /// </summary>
    public static Entity PredicateGeneratedBy {
      get { return new Entity(CedmaNameSpace + "GeneratedBy"); }
    }
    #endregion

    #region types and type relations
    public static Entity PredicateInstanceOf {
      get { return new Entity(CedmaNameSpace + "InstanceOf"); }
    }
    public static Entity TypeGeneticProgrammingFunctionTree {
      get { return new Entity(CedmaNameSpace + "FunctionTree"); }
    }
    public static Entity TypeDataSet {
      get { return new Entity(CedmaNameSpace + "DataSet"); }
    }
    public static Entity TypeAlgorithm {
      get { return new Entity(CedmaNameSpace + "Algorithm"); }
    }
    public static Entity TypeModel {
      get { return new Entity(CedmaNameSpace + "Model"); }
    }
    #endregion

    /// <summary>
    /// Wildcard entity for filtering.
    /// </summary>
    public static Entity AnyEntity {
      get { return new Entity(null); }
    }

  }
}
